from . import datastore, sidecar

SERVER_URL = "https://api.formalcloud.net"
SERVER_URL_V2 = "https://adminv2.api.formalcloud.net"


class Client(object):
    """Formal Admin API Client"""

    def __init__(self, api_key):
        """Constructor.

        Args:
            api_key: Formal API Key
        """

        self.DataStoreClient = datastore.DataStoreService(SERVER_URL_V2, api_key)
        self.SidecarClient = sidecar.SidecarService(SERVER_URL, api_key)



import os
import formal_sdk

if __name__ == '__main__':

    dataStoreId = ""
    nativeRoleId = ""
    nativeRoleSecret = ""
    useAsDefault = True
    apiKey = os.environ.get('TEST_API_KEY')

    newClient = formal_sdk.Client(apiKey)
    # Create Native Role
    createdRole = newClient.DataStoreClient.CreateNativeRole(dataStoreId=dataStoreId, nativeRoleId=nativeRoleId, nativeRoleSecret=nativeRoleSecret, useAsDefault=useAsDefault)

    # Get Native Role
    previousRole = newClient.DataStoreClient.GetNativeRole(dataStoreId=dataStoreId, nativeRoleId=nativeRoleId)

    print(f'DataStoreId: {previousRole.dataStoreId}')
    print(f'NativeRoleId: {previousRole.nativeRoleId}')
    print(f'NativeRoleSecret: {previousRole.nativeRoleSecret}')
    print(f'UseAsDefault: {previousRole.useAsDefault}')

    # Get sidecar tls cert by id
    sidecarId = ""
    certificate, privateKey, fullSecret = newClient.SidecarClient.GetTLSCertificate(sidecarId)



import json

import requests


class SidecarService:

    def __init__(self, SERVER_URL, token):
        self.BASE_URL = SERVER_URL
        self.headers = {
            'Content-Type': 'application/json',
            'X-Api-Key': token,
        }

    def GetTLSCertificate(self, sidecarId):

        url = f"{self.BASE_URL}/admin/sidecars/{sidecarId}/tlscert"
        response = requests.get(url, headers=self.headers)

        if response.status_code != 200:
            raise Exception(f'Request failed with status {response.status_code}')

        secret = json.loads(response.json().get('secret', {}))

        if 'certificate' not in secret or 'private_key' not in secret:
            raise Exception('Invalid response')

        return secret['certificate'], secret['private_key'], str(secret)



import requests
import json


class NativeRole:
    def __init__(self, datastoreId, nativeRoleId, nativeRoleSecret, useAsDefault):
        self.dataStoreId = datastoreId
        self.nativeRoleId = nativeRoleId
        self.nativeRoleSecret = nativeRoleSecret
        self.useAsDefault = useAsDefault

    def to_dict(self):
        return self.__dict__


class DataStoreService:

    def __init__(self, SERVER_URL, token):
        self.BASE_URL = SERVER_URL
        self.headers = {
            'Content-Type': 'application/json',
            'X-Api-Key': token,
        }

    def CreateNativeRole(self, dataStoreId, nativeRoleId, nativeRoleSecret, useAsDefault):
        url = f"{self.BASE_URL}/admin.v1.DataStoreService/CreateNativeRole"
        payload = {
            'dataStoreId': dataStoreId,
            'nativeRoleId': nativeRoleId,
            'nativeRoleSecret': nativeRoleSecret,
            'useAsDefault': useAsDefault,
        }
        response = requests.post(url, headers=self.headers, data=json.dumps(payload))

        if response.status_code != 200:
            raise Exception(f'Request failed with status {response.status_code}')

        native_role_data = response.json().get('nativeRole', {})
        return NativeRole(**native_role_data)

    def GetNativeRole(self, dataStoreId, nativeRoleId):
        url = f"{self.BASE_URL}/admin.v1.DataStoreService/GetNativeRole"
        payload = {
            'dataStoreId': dataStoreId,
            'nativeRoleId': nativeRoleId,
        }
        response = requests.post(url, headers=self.headers, data=json.dumps(payload))

        if response.status_code != 200:
            raise Exception(f'Request failed with status {response.status_code}')

        native_role_data = response.json().get('nativeRole', {})
        return NativeRole(**native_role_data)
